BarData class
Bar chart data
- Implemented types
Constructors
-
BarData({bool visible = true, ChartRotation rotation = ChartRotation.d0, ChartFlip flip = ChartFlip.none, Offset origin = Offset.zero, IChartLayout? layout, bool? crop, required List<
DataPoint> bars, ThicknessData thickness = const ThicknessData(size: 2.0), ThicknessData? border, double? borderRadius, IDataPointStyle? pointStyle}) -
const
Properties
-
bars
→ List<
DataPoint> -
final
- border → ThicknessData?
-
final
- borderRadius → double?
-
final
- crop → bool?
-
Whether to crop rendering to bounds (null uses chart default)
final
- flip → ChartFlip
-
Flip: none, vertically, horizontally, or both
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- layout → IChartLayout?
-
Optional layout override for this specific data series
final
- maxX → double
-
Maximum X coordinate from data points
no setteroverride
- maxY → double
-
Maximum Y coordinate from data points
no setteroverride
- minX → double
-
Minimum X coordinate from data points
no setteroverride
- minY → double
-
Minimum Y coordinate from data points
no setteroverride
- origin → Offset
-
Origin offset for positioning
final
- pointStyle → IDataPointStyle?
-
final
- renderer → IChartRenderer
-
Renderer for this chart type
no setteroverride
- rotation → ChartRotation
-
Rotation (d90/d270 use swapped dimensions so chart fills bounds)
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- thickness → ThicknessData
-
final
- visible → bool
-
Whether this chart is visible
final
Methods
-
copyWith(
{bool? visible, ChartRotation? rotation, ChartFlip? flip, Offset? origin, IChartLayout? layout, bool? crop, List< DataPoint> ? bars, ThicknessData? thickness, ThicknessData? border, double? borderRadius, IDataPointStyle? pointStyle}) → BarData -
lerpTo(
ISparklinesData next, double t) → ISparklinesData -
Interpolate between this and
nextusing interpolation factort(0.0 to 1.0)override -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
shouldRepaint(
ISparklinesData other) → bool -
Check if this chart should repaint compared to
otherReturns true if any property that affects rendering has changedoverride -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
- defaultRenderer → IChartRenderer
-
final