shouldRepaint method

  1. @override
bool shouldRepaint(
  1. ISparklinesData other
)
override

Check if this chart should repaint compared to other Returns true if any property that affects rendering has changed

Implementation

@override
bool shouldRepaint(ISparklinesData other) {
  if (other is! BarData) return true;
  if (visible != other.visible) return true;
  if (rotation != other.rotation) return true;
  if (flip != other.flip) return true;
  if (origin != other.origin) return true;
  if (layout != other.layout) return true;
  if (thickness != other.thickness) return true;
  if (bars.length != other.bars.length) return true;
  if (border != other.border) return true;
  if (borderRadius != other.borderRadius) return true;
  if (pointStyle != other.pointStyle) return true;

  for (int i = 0; i < bars.length; i++) {
    if (bars[i] != other.bars[i]) {
      return true;
    }
  }

  return false;
}