DataPointBounds extension

Extension on Iterable

on

Properties

maxX double

Available on Iterable<DataPoint>, provided by the DataPointBounds extension

Maximum X coordinate
no setter
maxY double

Available on Iterable<DataPoint>, provided by the DataPointBounds extension

Maximum Y coordinate (includes both offset y and final fy for correct bar/line bounds)
no setter
minX double

Available on Iterable<DataPoint>, provided by the DataPointBounds extension

Minimum X coordinate
no setter
minY double

Available on Iterable<DataPoint>, provided by the DataPointBounds extension

Minimum Y coordinate (includes both offset y and final fy for correct bar/line bounds)
no setter
sumDY double

Available on Iterable<DataPoint>, provided by the DataPointBounds extension

no setter