DataPointPipeline class

Constructors

DataPointPipeline({double snapEpsilon = 1e-9, int snapMultiplier = 1000000})

Properties

context DataPointPipelineContext
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

build(List<DataPoint> input) List<DataPoint>
normalize({double total = 1.0, double? threshold, DataPoint? thresholdPoint, double? spacing, bool? trailingSpacing}) DataPointPipeline
Normalize point.dy values
normalize2pi({double total = 2.0, double? threshold, double? spacing, double? spacingDeg, bool? trailingSpacing, DataPoint? thresholdPoint}) DataPointPipeline
Normalize point.dy values
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rescale({double currentMin = double.negativeInfinity, double currentMax = double.infinity, double targetMin = 0.0, double targetMax = 1.0}) DataPointPipeline
Linearly rescale intervals DataPoint.y..DataPoint.fy from currentMin..currentMax to targetMin..targetMax.
stack({double spacing = 0.0}) DataPointPipeline
Stack points on point.y by point.x with point.dy values
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited