NormalizeModifier class

Implemented types

Constructors

NormalizeModifier({required double low, required double high, double? mid, double? threshold})

Properties

hashCode int
The hash code for this object.
no setterinherited
high double
final
low double
final
mid double?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
threshold double?
threshold in normalized units
final

Methods

apply(List<DataPoint> input, DataPointPipelineContext context) List<DataPoint>
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited