shouldRepaint method

  1. @override
bool shouldRepaint(
  1. ISparklinesData other
)
override

Check if this chart should repaint compared to other Returns true if any property that affects rendering has changed

Implementation

@override
bool shouldRepaint(ISparklinesData other) {
  if (other is! LineData) return true;
  if (visible != other.visible) return true;
  if (rotation != other.rotation) return true;
  if (flip != other.flip) return true;
  if (origin != other.origin) return true;
  if (layout != other.layout) return true;
  if (line.length != other.line.length) return true;
  if (thickness != other.thickness) return true;
  if (areaGradient != other.areaGradient) return true;
  if (areaColor != other.areaColor) return true;
  if (areaFillType != other.areaFillType) return true;
  if (lineType != other.lineType) return true;
  if (pointStyle != other.pointStyle) return true;

  for (int i = 0; i < line.length; i++) {
    if (line[i] != other.line[i]) {
      return true;
    }
  }

  return false;
}