shouldRepaint method
Check if this chart should repaint compared to other
Returns true if any property that affects rendering has changed
Implementation
@override
bool shouldRepaint(ISparklinesData other) {
if (other is! PieData) return true;
if (visible != other.visible) return true;
if (rotation != other.rotation) return true;
if (flip != other.flip) return true;
if (origin != other.origin) return true;
if (layout != other.layout) return true;
if (pies.length != other.pies.length) return true;
if (thickness != other.thickness) return true;
if (pieOffset != other.pieOffset) return true;
if (padAngle != other.padAngle) return true;
if (border != other.border) return true;
if (borderRadius != other.borderRadius) return true;
for (int i = 0; i < pies.length; i++) {
if (pies[i] != other.pies[i]) {
return true;
}
}
return false;
}