SeatKey class

Annotations

Constructors

SeatKey({required String? label, required int row, required int column, Object? area, Set<Object> tags = const {}})

Properties

area Object?
final
column int
final
hashCode int
The hash code for this object.
no setteroverride
label String?
final
row int
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
tags Set<Object>
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override