SeatSelector class

Annotations

Constructors

SeatSelector({Set<String> labels = const {}, Set<int> rows = const {}, Set<int> columns = const {}, Set<Object?> areas = const {}, Set<Set<Object>> tags = const {}})

Properties

areas Set<Object?>
final
columns Set<int>
final
hashCode int
The hash code for this object.
no setterinherited
labels Set<String>
final
rows Set<int>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
tags Set<Set<Object>>
final

Methods

matches(SeatKey key) bool
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited