NullLabels class

Implemented types

Constructors

NullLabels()
const

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

next(int row, int column, Object? area) String?
Return the label for the next emitted seat.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
validate() → void
Validate the completed build and reset any per-build state.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited