SeatsBuilder class

Constructors

SeatsBuilder({double x = 0.0, double y = 0.0, double dy = 0.0, double z = 0.0, double seatDx = 1.0, double rowDy = 1.0, double gapDx = 0.0, double gapDy = 0.0, int row = 1, int column = 1, Object? area, Set<Object> tags = const {}, DataPointDataMap data = const {}, ISeatLabelBuilder labelBuilder = const NullLabels()})

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

area(Object? area) SeatsBuilder
build() List<DataPoint>
data(DataPointDataMap data) SeatsBuilder
gap({double? gapDx, double? gapDy}) SeatsBuilder
nextRow([int count = 1]) SeatsBuilder
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
record() SeatsBuilder
repeat(int count, {String? key}) SeatsBuilder
restoreState([String? key]) SeatsBuilder
saveOnlyState({String? key, bool gap = false, bool area = false, bool tags = false, bool data = false}) SeatsBuilder
saveRecord({required String key}) SeatsBuilder
saveState({String? key, bool gap = true, bool area = true, bool tags = true, bool data = true}) SeatsBuilder
seat({String? label, double? dy, double? z, Object? area = _seatAreaNotProvided, Set<Object>? tags, DataPointDataMap data = const {}}) SeatsBuilder
seats(int count, {ISeatLabelBuilder? labelBuilder, double? dy, double? z, Object? area = _seatAreaNotProvided, Set<Object>? tags, DataPointDataMap data = const {}}) SeatsBuilder
skip([int count = 1]) SeatsBuilder
tags(Set<Object> tags) SeatsBuilder
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited