ChartFlip enum

Chart flip: none, vertically, horizontally, or both. Vertically flips around horizontal axis; horizontally flips around vertical axis.

Inheritance
Available extensions

Values

none → const ChartFlip
vertically → const ChartFlip
horizontally → const ChartFlip
both → const ChartFlip

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

acrossX → const ChartFlip
acrossXY → const ChartFlip
acrossY → const ChartFlip
values → const List<ChartFlip>
A constant List of the values in this enum, in order of their declaration.