ChartTransform class
Properties
hashCode
→ int
The hash code for this object.
no setter inherited
runtimeType
→ Type
A representation of the runtime type of the object.
no setter inherited
Methods
antiScalar (double value )
→ double
If we cannot (re)draw the path after applying the transformation, we need to apply an anti-scaling factor to values such as stroke width, radius, and similar properties.
noSuchMethod (Invocation invocation )
→ dynamic
Invoked when a nonexistent method or property is accessed.
inherited
path (Path path )
→ Path
scalar (double value )
→ double
Apply transformation to scalar values like stroke width, radius, etc.
toString ()
→ String
A string representation of this object.
inherited
v3 (Vector3 v3 )
→ Vector3
xy (double x , double y )
→ Offset