DataPointMeta class

Inheritance
Implemented types

Constructors

DataPointMeta({int? id, String? key, String? label})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
id int?
final
key String?
final
label String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

lerp(DataPointMeta next, double t) DataPointMeta
inherited
lerpTo(IDataPointData next, double t) IDataPointData
Interpolate between this and next using interpolation factor t (0.0 to 1.0)
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited