IDataPointRenderer class abstract

Renders a single data point. The dataPoint argument is a DataPoint from package data (passed as Object to avoid circular imports).

Implementers

Constructors

IDataPointRenderer()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
render(Canvas canvas, ChartTransform transform, Paint paint, IDataPointStyle style, Object dataPoint) → void
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited