IDataPointStyle class abstract

Style interface for data points

Implemented types
Implementers

Constructors

IDataPointStyle()

Properties

hashCode int
The hash code for this object.
no setterinherited
renderer IDataPointRenderer
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

lerpTo(IDataPointStyle next, double t) IDataPointStyle
Interpolate between this and next using interpolation factor t (0.0 to 1.0)
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited