ILayoutData class abstract

Interface for layout dimensions

Implementers

Constructors

ILayoutData()

Properties

hashCode int
The hash code for this object.
no setterinherited
height double
no setter
maxX double
no setter
maxY double
no setter
minX double
no setter
minY double
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
width double
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited