interfaces/length_value library

Classes

Dx
A length measured as an X-axis data-space interval.
Dy
A length measured as a Y-axis data-space interval.
ILengthContext
Resolves unit-aware visual lengths for a chart's current viewport and data transform.
ILengthValue
A visual length that is resolved only when the chart transform is known.
Lp
Deferred interpolation between two length values.
Px
A length measured in Flutter logical pixels.
Vh
A CSS-style percentage of the logical viewport height (Vh(1) is 1%).
Vmax
A percentage of the longer logical viewport dimension (Vmax(1) is 1%).
Vmin
A percentage of the shorter logical viewport dimension (Vmin(1) is 1%).
Vw
A CSS-style percentage of the logical viewport width (Vw(1) is 1%).