ILengthContext class abstract interface

Resolves unit-aware visual lengths for a chart's current viewport and data transform.

Implementers

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
viewportHeight double
Logical viewport height for the chart, after its rotation dimension swap.
no setter
viewportWidth double
Logical viewport width for the chart, after its rotation dimension swap.
no setter

Methods

dataX(double value) double
Converts an X-axis data-space interval to a screen-space magnitude.
dataY(double value) double
Converts a Y-axis data-space interval to a screen-space magnitude.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited