lerpTo abstract method
Interpolate between this and next using interpolation factor t (0.0 to 1.0)
Implementation
T lerpTo(T next, double t);
Interpolate between this and next using interpolation factor t (0.0 to 1.0)
T lerpTo(T next, double t);