ILineTypeData class abstract

Marker interface for line type data

Implementers

Constructors

ILineTypeData()

Properties

hashCode int
The hash code for this object.
no setterinherited
isStrokeCapRound bool
no setter
isStrokeJoinRound bool
no setter
renderer ILineTypeRenderer
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited