ThicknessData class

Implemented types

Constructors

ThicknessData({required double size, Color color = const Color(0xFF000000), Gradient? gradient, double align = alignCenter})
const

Properties

align double
final
color Color
final
gradient Gradient?
Gradient has higher priority if set then color
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
size double
final

Methods

lerpTo(ThicknessData next, double t) ThicknessData
Interpolate between this and next using interpolation factor t (0.0 to 1.0)
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

alignCenter → const double
alignInside → const double
alignOutside → const double