ThicknessOverride class

Inheritance
Implemented types

Constructors

ThicknessOverride({double? size, Gradient? gradient, double? align, Color? color})
const

Properties

align double?
final
color Color?
final
gradient Gradient?
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
size double?
final

Methods

lerp(ThicknessOverride next, double t) ThicknessOverride
override
lerpTo(IDataPointData next, double t) IDataPointData
Interpolate between this and next using interpolation factor t (0.0 to 1.0)
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override