layout/chart_layout library

Classes

AbsoluteLayout
Math-oriented coordinates: origin at bottom-left, Y up. Prepares canvas by offsetting by height and scaling (1, -1).
RelativeLayout
Relative transformation to explicit bounds Can use infinity values for auto-calculation from data