RelativeLayout class
Relative transformation to explicit bounds Can use infinity values for auto-calculation from data
- Implemented types
Constructors
- RelativeLayout({double minX = 0, required double maxX, double minY = 0, required double maxY, RelativeDimension relativeTo = RelativeDimension.none})
-
const
- RelativeLayout.full({double minX = double.negativeInfinity, double maxX = double.infinity, double minY = double.negativeInfinity, double maxY = double.infinity, RelativeDimension relativeTo = RelativeDimension.none})
-
Full cover from min to max data
const
- RelativeLayout.normalized({double minX = 0.0, double maxX = 1.0, double minY = 0.0, double maxY = 1.0, RelativeDimension relativeTo = RelativeDimension.none})
-
const
- RelativeLayout.signed({double minX = -1.0, double maxX = 1.0, double minY = -1.0, double maxY = 1.0, RelativeDimension relativeTo = RelativeDimension.none})
-
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- maxX → double
-
final
- maxY → double
-
final
- minX → double
-
final
- minY → double
-
final
- relativeTo → RelativeDimension
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
resolve(
List< ILayoutData> dimensions) → IChartLayout -
Resolve layout with actual dimensions (e.g., resolve infinity values).
override
-
toString(
) → String -
A string representation of this object.
inherited
-
transform(
ILayoutData dimensions) → Matrix4 -
override
-
transformScalar(
double value, ILayoutData dimensions) → double -
Apply transformation to scalar values like stroke width, radius, etc.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited