AChartRenderer<DT extends ISparklinesData> class abstract

Implemented types
Implementers

Constructors

AChartRenderer()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

drawDataPoints(Canvas canvas, Paint paint, ChartTransform transform, IChartDataPointStyle chart, List<DataPoint> points) → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
render(Canvas canvas, ChartTransform transform, ISparklinesData data) → void
override
renderData(Canvas canvas, ChartTransform transform, DT data) → void
roundedRect(ChartTransform transform, IChartBorder border, Rect rect) RRect?
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited