CircleDataPointStyle class

Circle style for data points

Inheritance
Implemented types

Constructors

CircleDataPointStyle({required ILengthValue radius, required Color color})
const

Properties

color → Color
final
extent → ChartInsets
no setter
hashCode → int
The hash code for this object.
no setterinherited
radius → ILengthValue
final
renderer → IDataPointRenderer
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

lerp(CircleDataPointStyle next, double t) → CircleDataPointStyle
override
lerpTo(IDataPointData next, double t) → IDataPointData
Interpolate between this and next using interpolation factor t (0.0 to 1.0)
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

defaultRenderer ↔ IDataPointRenderer
getter/setter pair