ADataPointRenderer<ST extends IDataPointStyle> class
abstract
- Implemented types
- Implementers
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
render(
Canvas canvas, ChartTransform transform, Paint paint, IDataPointStyle style, Object dataPoint) → void -
override
-
renderStyle(
Canvas canvas, Paint paint, ChartTransform transform, ST style, DataPoint dataPoint) → void -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited