PieChartRenderer class
Properties
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
drawDataPoints(Canvas canvas, Paint paint, ChartTransform transform, IChartDataPointStyle chart, List<DataPoint> points)
→ void
-
inherited
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
render(Canvas canvas, ChartTransform transform, ISparklinesData data)
→ void
-
inherited
-
renderData(Canvas canvas, ChartTransform transform, PieData pieData)
→ void
-
override
-
roundedRect(ChartTransform transform, IChartBorder border, Rect rect)
→ RRect?
-
inherited
-
toString()
→ String
-
A string representation of this object.
inherited