BetweenLineData class

Between line chart data (fills area between two lines)

Implemented types
Mixed-in types
Available extensions

Constructors

BetweenLineData({bool visible = true, ChartRotation rotation = ChartRotation.d0, ChartFlip flip = ChartFlip.none, Offset origin = Offset.zero, IChartLayout? layout, bool? crop, ChartInsets padding = const ChartInsets(), required LineData from, required LineData to, Color areaColor = const Color(0xFF000000), Gradient? areaGradient, PathFillType? areaFillType})
const

Properties

areaColor → Color
final
areaFillType → PathFillType?
final
areaGradient → Gradient?
final
crop → bool?
Whether to crop rendering to bounds (null uses chart default)
final
first → DataPoint
The first element.
no setterinherited
flip → ChartFlip
Flip: none, vertically, horizontally, or both
final
from → LineData
final
hashCode → int
The hash code for this object.
no setterinherited
isEmpty → bool
Whether this collection has no elements.
no setterinherited
isNotEmpty → bool
Whether this collection has at least one element.
no setterinherited
iterator → Iterator<DataPoint>
A new Iterator that allows iterating the elements of this Iterable.
no setteroverride
last → DataPoint
The last element.
no setterinherited
layout → IChartLayout?
Optional layout override for this specific data series
final
length → int
The number of elements in this Iterable.
no setterinherited
maxX → double
Maximum X coordinate from data points
no setteroverride
maxX → double

Available on Iterable<DataPoint>, provided by the DataPointBounds extension

Maximum X coordinate
no setter
maxY → double
Maximum Y coordinate from data points
no setteroverride
maxY → double

Available on Iterable<DataPoint>, provided by the DataPointBounds extension

Maximum Y coordinate (includes both offset y and final fy for correct bar/line bounds)
no setter
minX → double
Minimum X coordinate from data points
no setteroverride
minX → double

Available on Iterable<DataPoint>, provided by the DataPointBounds extension

Minimum X coordinate
no setter
minY → double
Minimum Y coordinate from data points
no setteroverride
minY → double

Available on Iterable<DataPoint>, provided by the DataPointBounds extension

Minimum Y coordinate (includes both offset y and final fy for correct bar/line bounds)
no setter
origin → Offset
Origin offset for positioning
final
padding → ChartInsets
Additional padding applied to this chart's shared layout group.
final
renderer → IChartRenderer
Renderer for this chart type
no setteroverride
rotation → ChartRotation
Rotation (d90/d270 use swapped dimensions so chart fills bounds)
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
single → DataPoint
Checks that this iterable has only one element, and returns that element.
no setterinherited
sumDY → double

Available on Iterable<DataPoint>, provided by the DataPointBounds extension

no setter
supportsPointExtents → bool
Whether point IDataPointExtent metadata participates in fitting.
no setteroverride
to → LineData
final
visible → bool
Whether this chart is visible
final

Methods

any(bool test(DataPoint element)) → bool
Checks whether any element of this iterable satisfies test.
inherited
cast<R>() → Iterable<R>
A view of this iterable as an iterable of R instances.
inherited
contains(Object? element) → bool
Whether the collection contains an element equal to element.
inherited
copyWith({bool? visible, ChartRotation? rotation, ChartFlip? flip, Offset? origin, IChartLayout? layout, bool? crop, ChartInsets? padding, LineData? from, LineData? to, Color? color, Gradient? gradient, PathFillType? areaFillType}) → BetweenLineData
elementAt(int index) → DataPoint
Returns the indexth element.
inherited
every(bool test(DataPoint element)) → bool
Checks whether every element of this iterable satisfies test.
inherited
expand<T>(Iterable<T> toElements(DataPoint element)) → Iterable<T>
Expands each element of this Iterable into zero or more elements.
inherited
firstWhere(bool test(DataPoint element), {DataPoint orElse()?}) → DataPoint
The first element that satisfies the given predicate test.
inherited
fold<T>(T initialValue, T combine(T previousValue, DataPoint element)) → T
Reduces a collection to a single value by iteratively combining each element of the collection with an existing value
inherited
followedBy(Iterable<DataPoint> other) → Iterable<DataPoint>
Creates the lazy concatenation of this iterable and other.
inherited
forEach(void action(DataPoint element)) → void
Invokes action on each element of this iterable in iteration order.
inherited
join([String separator = ""]) → String
Converts each element to a String and concatenates the strings.
inherited
lastWhere(bool test(DataPoint element), {DataPoint orElse()?}) → DataPoint
The last element that satisfies the given predicate test.
inherited
lerpTo(ISparklinesData next, double t) → ISparklinesData
Interpolate between this and next using interpolation factor t (0.0 to 1.0)
override
map<T>(T toElement(DataPoint e)) → Iterable<T>
The current elements of this iterable modified by toElement.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
reduce(DataPoint combine(DataPoint value, DataPoint element)) → DataPoint
Reduces a collection to a single value by iteratively combining elements of the collection using the provided function.
inherited
shouldRepaint(ISparklinesData other) → bool
Check if this chart should repaint compared to other Returns true if any property that affects rendering has changed
override
singleWhere(bool test(DataPoint element), {DataPoint orElse()?}) → DataPoint
The single element that satisfies test.
inherited
skip(int count) → Iterable<DataPoint>
Creates an Iterable that provides all but the first count elements.
inherited
skipWhile(bool test(DataPoint element)) → Iterable<DataPoint>
Creates an Iterable that skips leading elements while test is satisfied.
inherited
take(int count) → Iterable<DataPoint>
Creates a lazy iterable of the count first elements of this iterable.
inherited
takeWhile(bool test(DataPoint element)) → Iterable<DataPoint>
Creates a lazy iterable of the leading elements satisfying test.
inherited
toList({bool growable = true}) → List<DataPoint>
Creates a List containing the elements of this Iterable.
inherited
toSet() → Set<DataPoint>
Creates a Set containing the same elements as this iterable.
inherited
toString() → String
Returns a string representation of (some of) the elements of this.
inherited
where(bool test(DataPoint element)) → Iterable<DataPoint>
Creates a new lazy Iterable with all elements that satisfy the predicate test.
inherited
whereType<T>() → Iterable<R>
Creates a new lazy Iterable with all elements that have type T.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

defaultRenderer → IChartRenderer
final