DataPoint class
A single data point with x, y coordinates and optional style DataPoint could be used as interface if needed
- Implemented types
- Available extensions
Constructors
Properties
- border → IDataPointBorder?
-
Available on DataPoint, provided by the DataPointExtension extension
no setter - data → DataPointDataMap
-
final
- dy → double
-
Value
final
- fy → double
-
Full Y (y + dy)
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- pieOffset → IPieOffset?
-
Available on DataPoint, provided by the DataPointExtension extension
no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- style → IDataPointStyle?
-
Available on DataPoint, provided by the DataPointExtension extension
no setter - thickness → IThicknessOverride?
-
Available on DataPoint, provided by the DataPointExtension extension
no setter - x → double
-
Offset by X
final
- y → double
-
Offset by Y
final
Methods
-
copyWith(
{double? x, double? dx, double? y, double? dy, double? fy, DataPointDataMap? data}) → DataPoint -
lerpTo(
DataPoint next, double t) → DataPoint -
Interpolate between this and
nextusing interpolation factort(0.0 to 1.0)override -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
of<
M> () → M? -
Available on DataPoint, provided by the DataPointExtension extension
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override