DataPoint class

A single data point with x, y coordinates and optional style

Implemented types

Constructors

DataPoint({required double x, double? dx, double y = 0.0, required double dy, IDataPointStyle? style, ThicknessOverride? thickness})
const

Properties

dx double?
Mainly used as offset of x in pie chart
final
dy double
Value
final
fy double
Full Y (y + dy)
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
style IDataPointStyle?
final
thickness ThicknessOverride?
final
x double
Offset by X
final
y double
Offset by Y
final

Methods

copyWith({double? x, double? dx, double? y, double? dy, IDataPointStyle? style, ThicknessOverride? thickness}) DataPoint
lerpTo(DataPoint next, double t) DataPoint
Interpolate between this and next using interpolation factor t (0.0 to 1.0)
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override