DataPointBounds extension
Extension on Iterable
Properties
- maxX → double
-
Available on Iterable<
Maximum X coordinateDataPoint> , provided by the DataPointBounds extensionno setter - maxY → double
-
Available on Iterable<
Maximum Y coordinate (includes both offset y and final fy for correct bar/line bounds)DataPoint> , provided by the DataPointBounds extensionno setter - minX → double
-
Available on Iterable<
Minimum X coordinateDataPoint> , provided by the DataPointBounds extensionno setter - minY → double
-
Available on Iterable<
Minimum Y coordinate (includes both offset y and final fy for correct bar/line bounds)DataPoint> , provided by the DataPointBounds extensionno setter - sumDY → double
-
Available on Iterable<
DataPoint> , provided by the DataPointBounds extensionno setter