DataPointPipeline class
Constructors
- DataPointPipeline({double spacing = 0.0})
Properties
- context → DataPointPipelineContext
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
build(
List< DataPoint> input) → List<DataPoint> -
normalize(
{double low = 0.0, double high = 1.0, double? mid, double? threshold}) → DataPointPipeline - Normalize point.dy values
-
normalize2pi(
{double low = 0.0, double high = 2 * pi, double? mid, double? threshold}) → DataPointPipeline - Normalize point.dy values
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
stack(
[bool enabled = true]) → DataPointPipeline - Stack points on point.y by point.x with point.dy values
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited