DataPointPipelineContext class
Constructors
- DataPointPipelineContext(double _snapEpsilon, int _snapMultiplier)
Properties
-
cumulativeByX
→ Map<
double, double> -
final
- globalMaxY ↔ double
-
getter/setter pair
- globalMinY ↔ double
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
snap(
double v) → double -
toString(
) → String -
A string representation of this object.
inherited
-
updateBounds(
Iterable< DataPoint> points) → void
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited