ScatterLineData class

Marker-only line type used by scatter plots.

Implemented types

Constructors

ScatterLineData()
const

Properties

drawLine bool
Whether this type draws connected line geometry and area fills.
no setteroverride
hashCode int
The hash code for this object.
no setterinherited
isStrokeCapRound bool
no setteroverride
isStrokeJoinRound bool
no setteroverride
minPoints int
Minimum number of points required by this line type renderer.
no setteroverride
renderer ILineTypeRenderer
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited