SteppedLineData class

Implemented types

Constructors

SteppedLineData({double stepJumpAt = 0.5, bool isStrokeCapRound = false, bool isStrokeJoinRound = false})
const
SteppedLineData.end({bool isStrokeCapRound = false, bool isStrokeJoinRound = false})
const
SteppedLineData.middle({bool isStrokeCapRound = false, bool isStrokeJoinRound = false})
const
SteppedLineData.start({bool isStrokeCapRound = false, bool isStrokeJoinRound = false})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
isStrokeCapRound bool
final
isStrokeJoinRound bool
final
renderer ILineTypeRenderer
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stepJumpAt double
0.0 → previous point, 1.0 → next point
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited