shouldRepaint method

  1. @override
bool shouldRepaint(
  1. ISparklinesData other
)
override

Check if this chart should repaint compared to other Returns true if any property that affects rendering has changed

Implementation

@override
bool shouldRepaint(ISparklinesData other) {
  if (other is! PieData) return true;
  if (visible != other.visible) return true;
  if (rotation != other.rotation) return true;
  if (origin != other.origin) return true;
  if (layout != other.layout) return true;
  if (points.length != other.points.length) return true;
  if (thickness != other.thickness) return true;
  if (dx != other.dx) return true;
  if (padAngle != other.padAngle) return true;
  if (border != other.border) return true;
  if (borderRadius != other.borderRadius) return true;

  for (int i = 0; i < points.length; i++) {
    if (points[i] != other.points[i]) {
      return true;
    }
  }

  return false;
}