PieSliceData class
Result of computing layout for a single pie slice (angle order, radii, space).
Constructors
Properties
- cornerRadius → double
-
final
- endAngle → double
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- innerRadius → double
-
final
- offset → Offset
-
final
- outerRadius → double
-
final
- padAngle → double
-
final
- point → DataPoint
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- startAngle → double
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toPath(
) → Path - Builds filled arc path using CircleArcBuilder with uniform thickness in screen space.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited