ChartInsets class
Screen-space insets applied inside the chart viewport or around a data point.
- Inheritance
-
- Object
- ADataPointData<
ChartInsets> - ChartInsets
- Implemented types
- Annotations
Constructors
- ChartInsets({ILengthValue? left, ILengthValue? top, ILengthValue? right, ILengthValue? bottom})
-
const
- ChartInsets.all(ILengthValue value)
-
const
- ChartInsets.horizontal(ILengthValue value)
-
const
- ChartInsets.vertical(ILengthValue value)
-
const
Properties
- bottom → ILengthValue?
-
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- isEmpty → bool
-
no setter
- left → ILengthValue?
-
final
- right → ILengthValue?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- top → ILengthValue?
-
final
Methods
-
lerp(
ChartInsets next, double t) → ChartInsets -
override
-
lerpTo(
IDataPointData next, double t) → IDataPointData -
Interpolate between this and
nextusing interpolation factort(0.0 to 1.0)inherited -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override