ChartRotation enum
Chart rotation: 0°, 90°, 180°, 270° (clockwise). For d90 and d270 the chart is laid out with width and height swapped so it fills the bounds when rotated.
Values
- d0 → const ChartRotation
- d90 → const ChartRotation
- d180 → const ChartRotation
- d270 → const ChartRotation
Properties
- angle → double
-
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
ChartRotation> - A constant List of the values in this enum, in order of their declaration.