ChartTransform class
Constructors
- ChartTransform({required IChartLayout layout, required ILayoutData dimensions, required Matrix4 pathTransform})
-
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
path(
Path path) → Path -
scalar(
double value) → double - Apply transformation to scalar values like stroke width, radius, etc.
-
toString(
) → String -
A string representation of this object.
inherited
-
v3(
Vector3 v3) → Vector3 -
xy(
double x, double y) → Offset
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited