antiScalar method
If we cannot (re)draw the path after applying the transformation, we need to apply an anti-scaling factor to values such as stroke width, radius, and similar properties.
Implementation
double antiScalar(double value) => value * _antiScalarK;