IChartLayout class abstract
Chart layout interface: applies canvas transformation so drawing uses data coordinates.
- Implementers
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
resolve(
List< ILayoutData> dimensions) → IChartLayout - Resolve layout with actual dimensions (e.g., resolve infinity values).
-
toString(
) → String -
A string representation of this object.
inherited
-
transform(
ILayoutData dimensions) → Matrix4 -
transformScalar(
double value, ILayoutData dimensions) → double - Apply transformation to scalar values like stroke width, radius, etc.
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited