Lp class final
Deferred interpolation between two length values.
This implementation is intentionally omitted from the package barrel; use ILengthValue.lerp instead of constructing it directly.
- Implemented types
Constructors
- Lp(ILengthValue a, ILengthValue b, double t)
-
const
Properties
- a → ILengthValue
-
final
- b → ILengthValue
-
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- t → double
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
resolve(
ILengthContext context) → double -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override