ILerpTo<T> class
abstract
Interface for types that can be interpolated
- Implementers
Constructors
- ILerpTo()
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
lerpTo(
T next, double t) → T -
Interpolate between this and
nextusing interpolation factort(0.0 to 1.0) -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited