ILineTypeData class abstract

Rendering configuration for a line type.

Implementers

Constructors

ILineTypeData()

Properties

drawLine bool
Whether this type draws connected line geometry and area fills.
no setter
hashCode int
The hash code for this object.
no setterinherited
isStrokeCapRound bool
no setter
isStrokeJoinRound bool
no setter
minPoints int
Minimum number of points required by this line type renderer.
no setter
renderer ILineTypeRenderer
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited