ILineTypeRenderer class abstract

Interface for line type renderers (path building + stroke rendering)

Implementers

Constructors

ILineTypeRenderer()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
render(Canvas canvas, ChartTransform transform, ILineChartData lineData) → void
toPath(ILineTypeData lineType, List<DataPoint> points, {bool reverse = false, Path? path}) Path
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited