ISparklinesData class abstract
Base interface for all chart data types
- Implemented types
- Implementers
Constructors
Properties
- crop → bool?
-
Whether to crop rendering to bounds (null uses chart default)
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- layout → IChartLayout?
-
Optional layout override for this specific data series
no setter
- maxX → double
-
Maximum X coordinate from data points
no setter
- maxY → double
-
Maximum Y coordinate from data points
no setter
- minX → double
-
Minimum X coordinate from data points
no setter
- minY → double
-
Minimum Y coordinate from data points
no setter
- origin → Offset
-
Origin offset for positioning
no setter
- renderer → IChartRenderer
-
Renderer for this chart type
no setter
- rotation → ChartRotation
-
Rotation (d90/d270 use swapped dimensions so chart fills bounds)
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- visible → bool
-
Whether this chart is visible
no setter
Methods
-
lerpTo(
ISparklinesData next, double t) → ISparklinesData -
Interpolate between this and
nextusing interpolation factort(0.0 to 1.0)inherited -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
shouldRepaint(
ISparklinesData other) → bool -
Check if this chart should repaint compared to
otherReturns true if any property that affects rendering has changed -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited