shouldRepaint abstract method
Check if this chart should repaint compared to other
Returns true if any property that affects rendering has changed
Implementation
bool shouldRepaint(ISparklinesData other);
Check if this chart should repaint compared to other
Returns true if any property that affects rendering has changed
bool shouldRepaint(ISparklinesData other);