AbsoluteLayout class

Math-oriented coordinates: origin at bottom-left, Y up. Prepares canvas by offsetting by height and scaling (1, -1).

Implemented types

Constructors

AbsoluteLayout()
const

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
resolve(List<ILayoutData> dimensions) IChartLayout
Resolve layout with actual dimensions (e.g., resolve infinity values).
override
toString() String
A string representation of this object.
inherited
transform(ILayoutData dimensions) Matrix4
override
transformScalar(double value, ILayoutData dimensions) double
Apply transformation to scalar values like stroke width, radius, etc.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited